@@ -1,12 +1,13 @@
 import ffi
+import _libc
 
 
-libc = ffi.open("libc.so.6")
+libc = _libc.get()
 
 fcntl_l = libc.func("i", "fcntl", "iil")
-fcntl_s = libc.func("i", "fcntl", "iis")
+fcntl_s = libc.func("i", "fcntl", "iip")
 ioctl_l = libc.func("i", "ioctl", "iil")
-ioctl_s = libc.func("i", "ioctl", "iis")
+ioctl_s = libc.func("i", "ioctl", "iip")
 
 
 def fcntl(fd, op, arg):
